/* Generated by wayland-scanner 1.20.0 */

#ifndef TEXT_SERVER_PROTOCOL_H
#define TEXT_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_text The text protocol
 * @section page_ifaces_text Interfaces
 * - @subpage page_iface_text_model - text model
 * - @subpage page_iface_text_model_factory - text model factory
 * @section page_copyright_text Copyright
 * <pre>
 *
 * Copyright © 2012 Intel Corporation
 * Copyright © 2013-2020 LG Electronics, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 * </pre>
 */
struct text_model;
struct text_model_factory;
struct wl_seat;
struct wl_surface;

#ifndef TEXT_MODEL_INTERFACE
#define TEXT_MODEL_INTERFACE
/**
 * @page page_iface_text_model text_model
 * @section page_iface_text_model_desc Description
 *
 * A model for text input. Adds support for text input and input methods to
 * applications. A text_model object is created from a text_model_factory and
 * corresponds typically to a text entry in an application. Requests are used
 * to activate/deactivate the model and set information like surrounding and
 * selected text or the content type. The information about entered text is
 * sent to the model via the pre-edit and commit events. Using this interface
 * removes the need for applications to directly process hardware key events
 * and compose text out of them.
 * @section page_iface_text_model_api API
 * See @ref iface_text_model.
 */
/**
 * @defgroup iface_text_model The text_model interface
 *
 * A model for text input. Adds support for text input and input methods to
 * applications. A text_model object is created from a text_model_factory and
 * corresponds typically to a text entry in an application. Requests are used
 * to activate/deactivate the model and set information like surrounding and
 * selected text or the content type. The information about entered text is
 * sent to the model via the pre-edit and commit events. Using this interface
 * removes the need for applications to directly process hardware key events
 * and compose text out of them.
 */
extern const struct wl_interface text_model_interface;
#endif
#ifndef TEXT_MODEL_FACTORY_INTERFACE
#define TEXT_MODEL_FACTORY_INTERFACE
/**
 * @page page_iface_text_model_factory text_model_factory
 * @section page_iface_text_model_factory_desc Description
 *
 * A factory for text models. This object is a singleton global.
 * @section page_iface_text_model_factory_api API
 * See @ref iface_text_model_factory.
 */
/**
 * @defgroup iface_text_model_factory The text_model_factory interface
 *
 * A factory for text models. This object is a singleton global.
 */
extern const struct wl_interface text_model_factory_interface;
#endif

#ifndef TEXT_MODEL_CONTENT_HINT_ENUM
#define TEXT_MODEL_CONTENT_HINT_ENUM
/**
 * @ingroup iface_text_model
 * content hint
 *
 * Content hint is a bitmask to allow to modify the behavior of the text
 * input.
 */
enum text_model_content_hint {
	/**
	 * no special behaviour
	 */
	TEXT_MODEL_CONTENT_HINT_NONE = 0x0,
	/**
	 * auto completion, correction and capitalization
	 */
	TEXT_MODEL_CONTENT_HINT_DEFAULT = 0x7,
	/**
	 * hidden and sensitive text
	 */
	TEXT_MODEL_CONTENT_HINT_PASSWORD = 0xc0,
	/**
	 * suggest word completions
	 */
	TEXT_MODEL_CONTENT_HINT_AUTO_COMPLETION = 0x1,
	/**
	 * suggest word corrections
	 */
	TEXT_MODEL_CONTENT_HINT_AUTO_CORRECTION = 0x2,
	/**
	 * switch to uppercase letters at the start of a sentence
	 */
	TEXT_MODEL_CONTENT_HINT_AUTO_CAPITALIZATION = 0x4,
	/**
	 * prefer lowercase letters
	 */
	TEXT_MODEL_CONTENT_HINT_LOWERCASE = 0x8,
	/**
	 * prefer uppercase letters
	 */
	TEXT_MODEL_CONTENT_HINT_UPPERCASE = 0x10,
	/**
	 * prefer casing for titles and headings (can be language dependend)
	 */
	TEXT_MODEL_CONTENT_HINT_TITLECASE = 0x20,
	/**
	 * characters should be hidden
	 */
	TEXT_MODEL_CONTENT_HINT_HIDDEN_TEXT = 0x40,
	/**
	 * typed text should not be stored
	 */
	TEXT_MODEL_CONTENT_HINT_SENSITIVE_DATA = 0x80,
	/**
	 * just latin characters should be entered
	 */
	TEXT_MODEL_CONTENT_HINT_LATIN = 0x100,
	/**
	 * the text input is multiline
	 */
	TEXT_MODEL_CONTENT_HINT_MULTILINE = 0x200,
};
#endif /* TEXT_MODEL_CONTENT_HINT_ENUM */

#ifndef TEXT_MODEL_CONTENT_PURPOSE_ENUM
#define TEXT_MODEL_CONTENT_PURPOSE_ENUM
/**
 * @ingroup iface_text_model
 * content purpose
 *
 * The content purpose allows to specify the primary purpose of a text input.
 *
 * This allows an input method to show special purpose input panels with extra
 * characters or to disallow some characters.
 */
enum text_model_content_purpose {
	/**
	 * default input, allowing all characters
	 */
	TEXT_MODEL_CONTENT_PURPOSE_NORMAL = 0,
	/**
	 * allow only alphabetic characters
	 */
	TEXT_MODEL_CONTENT_PURPOSE_ALPHA = 1,
	/**
	 * allow only digits
	 */
	TEXT_MODEL_CONTENT_PURPOSE_DIGITS = 2,
	/**
	 * input a number (including decimal separator and sign)
	 */
	TEXT_MODEL_CONTENT_PURPOSE_NUMBER = 3,
	/**
	 * input a phone number
	 */
	TEXT_MODEL_CONTENT_PURPOSE_PHONE = 4,
	/**
	 * input an URL
	 */
	TEXT_MODEL_CONTENT_PURPOSE_URL = 5,
	/**
	 * input an email address
	 */
	TEXT_MODEL_CONTENT_PURPOSE_EMAIL = 6,
	/**
	 * input a name of a person
	 */
	TEXT_MODEL_CONTENT_PURPOSE_NAME = 7,
	/**
	 * input a password (combine with password or sensitive_data hint)
	 */
	TEXT_MODEL_CONTENT_PURPOSE_PASSWORD = 8,
	/**
	 * input a date
	 */
	TEXT_MODEL_CONTENT_PURPOSE_DATE = 9,
	/**
	 * input a time
	 */
	TEXT_MODEL_CONTENT_PURPOSE_TIME = 10,
	/**
	 * input a date and time
	 */
	TEXT_MODEL_CONTENT_PURPOSE_DATETIME = 11,
	/**
	 * input for a terminal
	 */
	TEXT_MODEL_CONTENT_PURPOSE_TERMINAL = 12,
};
#endif /* TEXT_MODEL_CONTENT_PURPOSE_ENUM */

#ifndef TEXT_MODEL_ENTER_KEY_TYPE_ENUM
#define TEXT_MODEL_ENTER_KEY_TYPE_ENUM
/**
 * @ingroup iface_text_model
 * enter key type
 *
 * The enter key type can be used to alter the appearance of the enter key
 * on an input panel (virtual keyboard).
 */
enum text_model_enter_key_type {
	/**
	 * the default Enter key
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_DEFAULT = 0,
	/**
	 * show a Return button that inserts a new line
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_RETURN = 1,
	/**
	 * show a Done button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_DONE = 2,
	/**
	 * show a Go button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_GO = 3,
	/**
	 * show a Send button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_SEND = 4,
	/**
	 * show a Search button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_SEARCH = 5,
	/**
	 * show a Next button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_NEXT = 6,
	/**
	 * show a Previous button
	 */
	TEXT_MODEL_ENTER_KEY_TYPE_PREVIOUS = 7,
};
#endif /* TEXT_MODEL_ENTER_KEY_TYPE_ENUM */

#ifndef TEXT_MODEL_PREEDIT_STYLE_ENUM
#define TEXT_MODEL_PREEDIT_STYLE_ENUM
/**
 * @ingroup iface_text_model
 * pre-edit style
 *
 * The style for a composing text text.
 */
enum text_model_preedit_style {
	TEXT_MODEL_PREEDIT_STYLE_DEFAULT = 1,
	TEXT_MODEL_PREEDIT_STYLE_ACTIVE = 2,
	TEXT_MODEL_PREEDIT_STYLE_INACTIVE = 3,
	TEXT_MODEL_PREEDIT_STYLE_HIGHLIGHT = 4,
	TEXT_MODEL_PREEDIT_STYLE_UNDERLINE = 5,
	TEXT_MODEL_PREEDIT_STYLE_SELECTION = 6,
	TEXT_MODEL_PREEDIT_STYLE_INCORRECT = 7,
};
#endif /* TEXT_MODEL_PREEDIT_STYLE_ENUM */

/**
 * @ingroup iface_text_model
 * @struct text_model_interface
 */
struct text_model_interface {
	/**
	 * sets the surrounding text
	 *
	 * Sets the plain surrounding text around the input position.
	 * Cursor is the byte index within the surrounding text. Anchor is
	 * the byte index of the selection anchor within the surrounding
	 * text. If there is no selected text anchor is the same as cursor.
	 */
	void (*set_surrounding_text)(struct wl_client *client,
				     struct wl_resource *resource,
				     const char *text,
				     uint32_t cursor,
				     uint32_t anchor);
	/**
	 * request activation
	 *
	 * Requests the model to be activated (typically when the text
	 * entry gets focus). The seat argument is a wl_seat which
	 * maintains the focus for this activation. The surface argument is
	 * a wl_surface assigned to the model and tracked for focus lost.
	 * The activated event is emitted on successful activation.
	 */
	void (*activate)(struct wl_client *client,
			 struct wl_resource *resource,
			 uint32_t serial,
			 struct wl_resource *seat,
			 struct wl_resource *surface);
	/**
	 * request deactivation
	 *
	 * Requests the model to be deactivated (typically when the text
	 * entry lost focus). The seat argument is a wl_seat which was used
	 * for activation.
	 */
	void (*deactivate)(struct wl_client *client,
			   struct wl_resource *resource,
			   struct wl_resource *seat);
	/**
	 * reset
	 *
	 * Should be called by an editor widget when the input state
	 * should be reset, for example after the text was changed outside
	 * of the normal input method flow.
	 */
	void (*reset)(struct wl_client *client,
		      struct wl_resource *resource,
		      uint32_t serial);
	/**
	 * set_cursor_rectangle
	 *
	 * Sets a rectangle for the cursor with x, y, width and height in
	 * surface local coordinates.
	 *
	 * Not implemented.
	 */
	void (*set_cursor_rectangle)(struct wl_client *client,
				     struct wl_resource *resource,
				     int32_t x,
				     int32_t y,
				     int32_t width,
				     int32_t height);
	/**
	 * set content purpose and hint
	 *
	 * Sets the content purpose and content hint. While the purpose
	 * is the basic purpose of an input field, the hint flags allow to
	 * modify some of the behavior.
	 *
	 * When no content type is explicitly set, a normal content purpose
	 * with default hints (auto completion, auto correction, auto
	 * capitalization) should be assumed.
	 */
	void (*set_content_type)(struct wl_client *client,
				 struct wl_resource *resource,
				 uint32_t hint,
				 uint32_t purpose);
	/**
	 * invoke action
	 *
	 * Invokes a button action on a given position.
	 *
	 * Not implemented.
	 */
	void (*invoke_action)(struct wl_client *client,
			      struct wl_resource *resource,
			      uint32_t button,
			      uint32_t index);
	/**
	 * commit state
	 *
	 * Requests to apply state changes sent so far.
	 */
	void (*commit)(struct wl_client *client,
		       struct wl_resource *resource);
	/**
	 * show input panels
	 *
	 * Requests input panels (virtual keyboard) to show.
	 */
	void (*show_input_panel)(struct wl_client *client,
				 struct wl_resource *resource);
	/**
	 * hide input panels
	 *
	 * Requests input panels (virtual keyboard) to hide.
	 */
	void (*hide_input_panel)(struct wl_client *client,
				 struct wl_resource *resource);
	/**
	 * set max length of input field
	 *
	 * Sets the maximum length of an input field.
	 */
	void (*set_max_text_length)(struct wl_client *client,
				    struct wl_resource *resource,
				    uint32_t length);
	/**
	 * set platform specific data
	 *
	 * Sets the platform specific data (text).
	 */
	void (*set_platform_data)(struct wl_client *client,
				  struct wl_resource *resource,
				  const char *text);
	/**
	 * set type of enter key
	 *
	 * Sets the type of the enter key on an input panel (virtual
	 * keyboard).
	 */
	void (*set_enter_key_type)(struct wl_client *client,
				   struct wl_resource *resource,
				   uint32_t enter_key_type);
	/**
	 * set rect of the input panel
	 *
	 * Requests the geometry of the input panel to change. The
	 * geometry should be in surface local coordinates.
	 */
	void (*set_input_panel_rect)(struct wl_client *client,
				     struct wl_resource *resource,
				     int32_t x,
				     int32_t y,
				     uint32_t width,
				     uint32_t height);
	/**
	 * reset rect of the input panel
	 *
	 * Resets the geometry of the input panel requested.
	 */
	void (*reset_input_panel_rect)(struct wl_client *client,
				       struct wl_resource *resource);
};

#define TEXT_MODEL_COMMIT_STRING 0
#define TEXT_MODEL_PREEDIT_STRING 1
#define TEXT_MODEL_DELETE_SURROUNDING_TEXT 2
#define TEXT_MODEL_CURSOR_POSITION 3
#define TEXT_MODEL_PREEDIT_STYLING 4
#define TEXT_MODEL_PREEDIT_CURSOR 5
#define TEXT_MODEL_MODIFIERS_MAP 6
#define TEXT_MODEL_KEYSYM 7
#define TEXT_MODEL_ENTER 8
#define TEXT_MODEL_LEAVE 9
#define TEXT_MODEL_INPUT_PANEL_STATE 10
#define TEXT_MODEL_INPUT_PANEL_RECT 11

/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_COMMIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_PREEDIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_DELETE_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_CURSOR_POSITION_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_PREEDIT_STYLING_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_PREEDIT_CURSOR_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_MODIFIERS_MAP_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_KEYSYM_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_ENTER_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_LEAVE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_INPUT_PANEL_STATE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_INPUT_PANEL_RECT_SINCE_VERSION 1

/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_ACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_DEACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_RESET_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_CURSOR_RECTANGLE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_CONTENT_TYPE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_INVOKE_ACTION_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_COMMIT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SHOW_INPUT_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_HIDE_INPUT_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_MAX_TEXT_LENGTH_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_PLATFORM_DATA_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_ENTER_KEY_TYPE_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_SET_INPUT_PANEL_RECT_SINCE_VERSION 1
/**
 * @ingroup iface_text_model
 */
#define TEXT_MODEL_RESET_INPUT_PANEL_RECT_SINCE_VERSION 1

/**
 * @ingroup iface_text_model
 * Sends an commit_string event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_commit_string(struct wl_resource *resource_, uint32_t serial, const char *text)
{
	wl_resource_post_event(resource_, TEXT_MODEL_COMMIT_STRING, serial, text);
}

/**
 * @ingroup iface_text_model
 * Sends an preedit_string event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_preedit_string(struct wl_resource *resource_, uint32_t serial, const char *text, const char *commit)
{
	wl_resource_post_event(resource_, TEXT_MODEL_PREEDIT_STRING, serial, text, commit);
}

/**
 * @ingroup iface_text_model
 * Sends an delete_surrounding_text event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_delete_surrounding_text(struct wl_resource *resource_, uint32_t serial, int32_t index, uint32_t length)
{
	wl_resource_post_event(resource_, TEXT_MODEL_DELETE_SURROUNDING_TEXT, serial, index, length);
}

/**
 * @ingroup iface_text_model
 * Sends an cursor_position event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_cursor_position(struct wl_resource *resource_, uint32_t serial, int32_t index, int32_t anchor)
{
	wl_resource_post_event(resource_, TEXT_MODEL_CURSOR_POSITION, serial, index, anchor);
}

/**
 * @ingroup iface_text_model
 * Sends an preedit_styling event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_preedit_styling(struct wl_resource *resource_, uint32_t serial, uint32_t index, uint32_t length, uint32_t style)
{
	wl_resource_post_event(resource_, TEXT_MODEL_PREEDIT_STYLING, serial, index, length, style);
}

/**
 * @ingroup iface_text_model
 * Sends an preedit_cursor event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_preedit_cursor(struct wl_resource *resource_, uint32_t serial, int32_t index)
{
	wl_resource_post_event(resource_, TEXT_MODEL_PREEDIT_CURSOR, serial, index);
}

/**
 * @ingroup iface_text_model
 * Sends an modifiers_map event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_modifiers_map(struct wl_resource *resource_, struct wl_array *map)
{
	wl_resource_post_event(resource_, TEXT_MODEL_MODIFIERS_MAP, map);
}

/**
 * @ingroup iface_text_model
 * Sends an keysym event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_keysym(struct wl_resource *resource_, uint32_t serial, uint32_t time, uint32_t sym, uint32_t state, uint32_t modifiers)
{
	wl_resource_post_event(resource_, TEXT_MODEL_KEYSYM, serial, time, sym, state, modifiers);
}

/**
 * @ingroup iface_text_model
 * Sends an enter event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_enter(struct wl_resource *resource_, struct wl_resource *surface)
{
	wl_resource_post_event(resource_, TEXT_MODEL_ENTER, surface);
}

/**
 * @ingroup iface_text_model
 * Sends an leave event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_leave(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, TEXT_MODEL_LEAVE);
}

/**
 * @ingroup iface_text_model
 * Sends an input_panel_state event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_input_panel_state(struct wl_resource *resource_, uint32_t state)
{
	wl_resource_post_event(resource_, TEXT_MODEL_INPUT_PANEL_STATE, state);
}

/**
 * @ingroup iface_text_model
 * Sends an input_panel_rect event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
text_model_send_input_panel_rect(struct wl_resource *resource_, int32_t x, int32_t y, uint32_t width, uint32_t height)
{
	wl_resource_post_event(resource_, TEXT_MODEL_INPUT_PANEL_RECT, x, y, width, height);
}

/**
 * @ingroup iface_text_model_factory
 * @struct text_model_factory_interface
 */
struct text_model_factory_interface {
	/**
	 * create text model
	 *
	 * Creates a new text model object.
	 */
	void (*create_text_model)(struct wl_client *client,
				  struct wl_resource *resource,
				  uint32_t id);
};


/**
 * @ingroup iface_text_model_factory
 */
#define TEXT_MODEL_FACTORY_CREATE_TEXT_MODEL_SINCE_VERSION 1

#ifdef  __cplusplus
}
#endif

#endif
